@@ -26,28 +26,11 @@ via connections to the Osram hub.
 
 =head1 DESCRIPTION
 
-This module will connect to an Osram Lightify hub, allowing the
-control of lights via Perl.
+This module is work-in-progress and currently allows only global/broadcast
+actions to be carried out, along with the discovery of nodes.
 
-The communication with the hub is carried out by sending/receiving
-binary messages to the hub on port 4000.  The specific bytes set
-have been documented in the L<Osram::Lightify::API> module.
-
-This module is responsible for:
-
-=over 8
-
-=item Identifying lights:
-
-We can initiate a discovery of all the available lights, and create
-a suitable L<Osram::Lightify::Light> object for each discovered light.
-
-=item Sending broadcast events:
-
-We can send a broadcast event, which applies to all known lights,
-to instruct them to go on or off.
-
-=back
+In the future it will be possible to control the nodes we've discovered
+dynamically.
 
 =cut
 
@@ -88,7 +71,7 @@ sub new
 
 =head2 all_on
 
-Broadcast an "on" event to all lights.
+Switch all known nodes on.
 
 =cut
 
@@ -97,7 +80,7 @@ sub all_on
     my ($self) = (@_);
 
     # Get the open socket
-    $self->_connect() unless ( $self->{ '_socket' } );
+    $self->_connect() unless( $self->{'_socket'} );
     my $sock = $self->{ '_socket' };
 
     # Send the magic to initiate "All On"
@@ -117,7 +100,7 @@ sub all_on
 
 =head2 all_off
 
-Broadcast an "off" event to all lights.
+Switch all known nodes off.
 
 =cut
 
@@ -126,7 +109,7 @@ sub all_off
     my ($self) = (@_);
 
     # Get the open socket
-    $self->_connect() unless ( $self->{ '_socket' } );
+    $self->_connect() unless( $self->{'_socket'} );
     my $sock = $self->{ '_socket' };
 
     # Send the magic to initiate "All Off"
@@ -160,7 +143,7 @@ sub lights
     my @ret;
 
     # Get the open socket
-    $self->_connect() unless ( $self->{ '_socket' } );
+    $self->_connect() unless( $self->{'_socket'} );
     my $sock = $self->{ '_socket' };
 
     # Send the magic to initiate a scan.
@@ -208,7 +191,7 @@ sub lights
 
 Private and internal-method.
 
-Connect to the hub, via the C<host> parameter we were given in our constructor.
+Connect to the hub, via the host we were given in our constructor.
 
 =end doc
 
@@ -273,46 +256,6 @@ sub _read
 }
 
 
-=begin doc _session_token
-
-Private and internal-method.
-
-Generate and return a four-byte token.  All the mutator commands
-for the light-devices take such a thing.  It doesn't seem to matter
-what we set, so I've encoded the seconds-past-the-epoch.
-
-Setting a value avoids commands being dropped as "old"/"reused".
-
-=end doc
-
-=cut
-
-sub _session_token()
-{
-    my $time = time();
-    $time = sprintf( "%x", time );
-
-    my $t = "";
-
-    if ( $time =~ /^(..)(..)(..)(..)$/ )
-    {
-        $t .= chr( hex($1) );
-        $t .= chr( hex($2) );
-        $t .= chr( hex($3) );
-        $t .= chr( hex($4) );
-    }
-    else
-    {
-
-        $t .= chr( hex("0x00") );
-        $t .= chr( hex("0x00") );
-        $t .= chr( hex("0x00") );
-        $t .= chr( hex("0x00") );
-    }
-    return ($t);
-}
-
-
 1;
 
 
